<?php

namespace Repository;

use Doctrine\ORM\EntityManager;
use Doctrine\DBAL\Connection;
use Util\InstanceProvider;
use Teknisa\Model\Traits\TQuery;
use Zeedhi\DevOps\Util\Utilities;

class ValoresOrcaCli
{
    use TQuery;

    /**
     * @var EntityManager
     */
    private $entityManager;

    /**
     * ValoresOrcaCli constructor.
     * @param EntityManager $entityManager
     */
    public function __construct(EntityManager $entityManager)
    {
        $this->entityManager = $entityManager;
    }

    public function updateNrParcelaCliente($qtparccust, $cdcliente)
    {
        $query = <<<SQL
            UPDATE CLIENTE
            SET     QTPARCCUST = :QTPARCCUST
            WHERE
                    CDCLIENTE = :CDCLIENTE
                   
SQL;
        $params = array(
            'QTPARCCUST'    => $qtparccust,
            'CDCLIENTE'     => $cdcliente,
        );

        return $this->entityManager->getConnection()->executeQuery($query, $params);
    }

    public function qryVigencia($cdcliente)
    {
        $query = <<<SQL
            SELECT DISTINCT TO_CHAR(DTINIVAITORC,'DD/MM/YYYY') AS DTINIVAITORC
            FROM ITEMORCACLIE
            WHERE CDCLIENTE = :P_CDCLIENTE
            ORDER BY DTINIVAITORC DESC
SQL;

        $params = array(
            'P_CDCLIENTE'       => $cdcliente,
        );

        return $this->createAndExecuteQueryAndBuildResponseData(InstanceProvider::getEntityManager(), $query, $params);
    }

    public function qryItemOrca($cdcliente, $dtinivaitorc)
    {
        $query = <<<SQL
                SELECT P.CDITORCAPROD, I.VRITORCACLIE, P.NMITORCAPROD, I.DTINIVAITORC, I.CDCLIENTE
                FROM ITEMORCACLIE I, ITEMORCAPROD P
                WHERE
                    I.CDCLIENTE   (+) = :P_CDCLIENTE AND
                    I.DTINIVAITORC(+) = :P_DTINIVAITORC   AND
                    I.CDITORCAPROD(+) = P.CDITORCAPROD AND
                    P.IDSTITORCPRO = 'A'
                ORDER BY P.CDITORCAPROD
SQL;

        $params = array(
            'P_CDCLIENTE'       => $cdcliente,
            'P_DTINIVAITORC'    => $dtinivaitorc,
        );

        return $this->createAndExecuteQueryAndBuildResponseData(InstanceProvider::getEntityManager(), $query, $params);
    }

    public function updateItemOrcaClie($vritorcaclie, $cdcliente, $cditorcaprod, $dtinicaitorc)
    {
        $query = <<<SQL
            UPDATE ITEMORCACLIE
            SET     CDCLIENTE = :CDCLIENTE,
                    CDITORCAPROD = :CDITORCAPROD,
                    VRITORCACLIE = :VRITORCACLIE,
                    DTINIVAITORC = :DTINIVAITORC
            WHERE
                    CDCLIENTE = :CDCLIENTE AND
                    CDITORCAPROD = :CDITORCAPROD
                   
SQL;
        $params = array(
            'VRITORCACLIE'  => $vritorcaclie,
            'CDCLIENTE'     => $cdcliente,
            'CDITORCAPROD'  => $cditorcaprod,
            'DTINIVAITORC'  => $dtinicaitorc,
        );

        return $this->entityManager->getConnection()->executeQuery($query, $params);
    }

    public function insertItemOrcaClie($vritorcaclie, $cdcliente, $cditorcaprod, $dtinicaitorc)
    {
        $query = <<<SQL
            INSERT INTO ITEMORCACLIE
            (CDCLIENTE, CDITORCAPROD, VRITORCACLIE, DTINIVAITORC)
            VALUES
            (:CDCLIENTE, :CDITORCAPROD, :VRITORCACLIE, :DTINIVAITORC)
                   
SQL;
        $params = array(
            'VRITORCACLIE'  => $vritorcaclie,
            'CDCLIENTE'     => $cdcliente,
            'CDITORCAPROD'  => $cditorcaprod,
            'DTINIVAITORC'  => $dtinicaitorc,
        );

        return $this->entityManager->getConnection()->executeQuery($query, $params);
    }

    public function qryDelItemOrca($cdcliente)
    {
        $query = <<<SQL
            DELETE FROM ITEMORCACLIE
            WHERE CDCLIENTE = :CDCLIENTE
                   
SQL;
        $params = array(
            'CDCLIENTE'        => $cdcliente,
        );

        return $this->entityManager->getConnection()->executeQuery($query, $params);
    }

    public function qryDelValorItemOrca($cdcliente, $cditorcaprod, $dtinicaitorc)
    {
        $query = <<<SQL
            DELETE FROM ITEMORCACLIE
            WHERE CDCLIENTE = :CDCLIENTE AND
            CDITORCAPROD = :CDITORCAPROD AND
            TO_CHAR(DTINIVAITORC,'DD/MM/YYYY') = :DTINIVAITORC
                   
SQL;
        $params = array(
            'CDCLIENTE'        => $cdcliente,
            'CDITORCAPROD'     => $cditorcaprod,
            'DTINIVAITORC'     => $dtinicaitorc
        );

        return $this->entityManager->getConnection()->executeQuery($query, $params);
    }
}
